==> epiphany-0.6.1.tar.bz2: epiphany-0.6.1/embed/ephy-embed-prefs.h <==
#define CONF_NETWORK_SOCKS_PROXY_VERSION "/apps/epiphany/network/socks_proxy_version"
#define CONF_NETWORK_NO_PROXIES_FOR "/apps/epiphany/network/no_proxies_for"
#define CONF_NETWORK_DISK_CACHE "/apps/epiphany/network/disk_cache_size"
#define CONF_NETWORK_MEMORY_CACHE "/apps/epiphany/network/mem_cache_size"
#define CONF_NETWORK_CACHE_COMPARE "/apps/epiphany/network/cache_compare"
#define CONF_NETWORK_USER_AGENT "/apps/epiphany/network/user_agent"
#define CONF_RENDERING_FONT "/apps/epiphany/rendering/font"
#define CONF_RENDERING_FONT_VAR_SIZE "/apps/epiphany/rendering/font_var_size"
#define CONF_RENDERING_FONT_FIXED_SIZE "/apps/epiphany/rendering/font_fixed_size"
#define CONF_RENDERING_FONT_MIN_SIZE "/apps/epiphany/rendering/font_min_size"
#define CONF_RENDERING_LANGUAGE "/apps/epiphany/rendering/lang"
#define CONF_RENDERING_USE_OWN_COLORS "/apps/epiphany/rendering/use_own_colors"
#define CONF_RENDERING_USE_SYSTEM_COLORS "/apps/epiphany/rendering/use_system_colors"
#define CONF_RENDERING_USE_OWN_FONTS "/apps/epiphany/rendering/use_own_fonts"
#define CONF_RENDERING_BG_COLOR "/apps/epiphany/rendering/background_color"
#define CONF_RENDERING_TEXT_COLOR "/apps/epiphany/rendering/text_color"
#define CONF_RENDERING_VISITED_LINKS "/apps/epiphany/rendering/visited_link_color"
#define CONF_RENDERING_UNVISITED_LINKS "/apps/epiphany/rendering/unvisited_link_color"
#define CONF_RENDERING_UNDERLINE_LINKS "/apps/epiphany/rendering/underline_links"
#define CONF_SECURITY_ALLOW_POPUPS "/apps/epiphany/security/allow_popups"
#define CONF_SECURITY_JAVA_ENABLED "/apps/epiphany/security/java_enabled"
#define CONF_SECURITY_JAVASCRIPT_ENABLED "/apps/epiphany/security/javascript_enabled"
#define CONF_SECURITY_COOKIES_ACCEPT "/apps/epiphany/security/cookie_accept"
#define CONF_LANGUAGE_AUTODETECT_CHARSET "/apps/epiphany/rendering/autodetect_charset"
#define CONF_LANGUAGE_DEFAULT_CHARSET "/apps/epiphany/rendering/default_charset"
#define CONF_RENDERING_DEFAULT_FONT "/apps/epiphany/rendering/default_font"
#define CONF_FILTERING_DEFAULT_STATUSBAR "/apps/epiphany/filtering/default_allow_statusbar"

/* These are defined gnome wide now */
#define CONF_NETWORK_PROXY_MODE "/system/proxy/mode"
#define CONF_NETWORK_HTTP_PROXY "/system/http_proxy/host"
#define CONF_NETWORK_SSL_PROXY "/system/proxy/secure_host"
#define CONF_NETWORK_FTP_PROXY "/system/proxy/ftp_host"
#define CONF_NETWORK_SOCKS_PROXY "/system/proxy/socks_host"
#define CONF_NETWORK_HTTP_PROXY_PORT "/system/http_proxy/port"
#define CONF_NETWORK_SSL_PROXY_PORT "/system/proxy/secure_port"
#define CONF_NETWORK_FTP_PROXY_PORT "/system/proxy/ftp_port"
#define CONF_NETWORK_SOCKS_PROXY_PORT "/system/proxy/socks_port"
#define CONF_NETWORK_PROXY_AUTO_URL "/system/proxy/autoconfig_url"

==> epiphany-0.7.0.tar.bz2: epiphany-0.7.0/embed/ephy-embed-prefs.h <==
#define CONF_NETWORK_SOCKS_PROXY_VERSION "/apps/epiphany/network/socks_proxy_version"
#define CONF_NETWORK_NO_PROXIES_FOR "/apps/epiphany/network/no_proxies_for"
#define CONF_NETWORK_DISK_CACHE "/apps/epiphany/network/disk_cache_size"
#define CONF_NETWORK_MEMORY_CACHE "/apps/epiphany/network/mem_cache_size"
#define CONF_NETWORK_CACHE_COMPARE "/apps/epiphany/network/cache_compare"
#define CONF_NETWORK_USER_AGENT "/apps/epiphany/network/user_agent"
#define CONF_RENDERING_FONT "/apps/epiphany/rendering/font"
#define CONF_RENDERING_FONT_VAR_SIZE "/apps/epiphany/rendering/font_var_size"
#define CONF_RENDERING_FONT_FIXED_SIZE "/apps/epiphany/rendering/font_fixed_size"
#define CONF_RENDERING_FONT_MIN_SIZE "/apps/epiphany/rendering/font_min_size"
#define CONF_RENDERING_LANGUAGE "/apps/epiphany/rendering/lang"
#define CONF_RENDERING_USE_OWN_COLORS "/apps/epiphany/rendering/use_own_colors"
#define CONF_RENDERING_USE_OWN_FONTS "/apps/epiphany/rendering/use_own_fonts"
#define CONF_RENDERING_UNDERLINE_LINKS "/apps/epiphany/rendering/underline_links"
#define CONF_SECURITY_ALLOW_POPUPS "/apps/epiphany/security/allow_popups"
#define CONF_SECURITY_JAVA_ENABLED "/apps/epiphany/security/java_enabled"
#define CONF_SECURITY_JAVASCRIPT_ENABLED "/apps/epiphany/security/javascript_enabled"
#define CONF_SECURITY_COOKIES_ACCEPT "/apps/epiphany/security/cookie_accept"
#define CONF_LANGUAGE_AUTODETECT_ENCODING "/apps/epiphany/rendering/autodetect_encoding"
#define CONF_LANGUAGE_DEFAULT_ENCODING "/apps/epiphany/rendering/default_encoding"
#define CONF_RENDERING_DEFAULT_FONT "/apps/epiphany/rendering/default_font"
#define CONF_FILTERING_DEFAULT_STATUSBAR "/apps/epiphany/filtering/default_allow_statusbar"

/* These are defined gnome wide now */
#define CONF_NETWORK_PROXY_MODE "/system/proxy/mode"
#define CONF_NETWORK_HTTP_PROXY "/system/http_proxy/host"
#define CONF_NETWORK_SSL_PROXY "/system/proxy/secure_host"
#define CONF_NETWORK_FTP_PROXY "/system/proxy/ftp_host"
#define CONF_NETWORK_SOCKS_PROXY "/system/proxy/socks_host"
#define CONF_NETWORK_HTTP_PROXY_PORT "/system/http_proxy/port"
#define CONF_NETWORK_SSL_PROXY_PORT "/system/proxy/secure_port"
#define CONF_NETWORK_FTP_PROXY_PORT "/system/proxy/ftp_port"
#define CONF_NETWORK_SOCKS_PROXY_PORT "/system/proxy/socks_port"
#define CONF_NETWORK_PROXY_AUTO_URL "/system/proxy/autoconfig_url"
